# Matplotlib backend

```{eval-rst}
.. currentmodule:: plopp

.. autosummary::
   :toctree: ../generated

   backends.matplotlib.MatplotlibBackend
   backends.matplotlib.canvas.Canvas
   backends.matplotlib.line.Line
   backends.matplotlib.image.Image
   backends.matplotlib.scatter.Scatter
   backends.matplotlib.static.StaticFig
   backends.matplotlib.interactive.InteractiveFig
   backends.matplotlib.tiled.Tiled
```
